class CorpusTokenList extends ResourceList {
  static autoInit() {
    for (let corpusTokenListElement of document.querySelectorAll('.corpus-token-list:not(.no-autoinit)')) {
      new CorpusTokenList(corpusTokenListElement);
    }
  }

  static defaultOptions = {
    page: 100
  };

  constructor(listContainerElement, options = {}) {
    let _options = Utils.mergeObjectsDeep(
      CorpusTokenList.defaultOptions,
      options
    );
    super(listContainerElement, _options);
    this.listjs.list.addEventListener('click', (event) => {this.onClick(event)});
    this.selectedItemIds = new Set();

  }

  get item() {
    return (values) => {
      return `
        <tr class="list-item clickable hoverable">
          <td>
            <label class="list-action-trigger" data-list-action="select">
              <input class="select-checkbox" type="checkbox" ${values.mostFrequent ? 'checked="checked"' : ''}>
              <span class="disable-on-click"></span>
            </label>
          </td>
          <td><span class="term"></span></td>
          <td><span class="count"></span></td>
          <td><span class="frequency"></span></td>
        </tr>
      `.trim();
    }
  }

  get valueNames() {
    return [
      'term',
      'count',
      'mostFrequent',
      'frequency'
    ];
  }

  initListContainerElement() {
    if (!this.listContainerElement.hasAttribute('id')) {
      this.listContainerElement.id = Utils.generateElementId('corpus-token-list-');
    }
    let listSearchElementId = Utils.generateElementId(`${this.listContainerElement.id}-search-`);
    this.listContainerElement.innerHTML = `
      <div class="input-field">
        <i class="material-icons prefix">search</i>
        <input id="${listSearchElementId}" class="search" type="text"></input>
        <label for="${listSearchElementId}">Search token</label>
      </div>
      <div class="scrollable-list-container-wrapper" style="height:276px; overflow:scroll;">
        <div class="scrollable-list-container">
          <table>
            <thead>
              <tr>
                <th></th>
                <th>Term</th>
                <th>Count</th>
                <th>Frequency</th>
              </tr>
            </thead>
            <tbody class="list"></tbody>
          </table>
        </div>
      </div>
      <ul class="pagination"></ul>
    `.trim();
    this.listContainerElement.style.padding = '30px';
  }

  mapResourceToValue(corpusTokenData) {
    return {
      term: corpusTokenData.term,
      count: corpusTokenData.count,
      mostFrequent: corpusTokenData.mostFrequent,
      frequency: '-'
    };
  }

  sort() {
    this.listjs.sort('count', {order: 'desc'});
  }

  onClick(event) {
    let listItemElement = event.target.closest('.list-item[data-id]');
    if (listItemElement === null) {return;}
    let itemId = listItemElement.dataset.id;
    let listActionElement = event.target.closest('.list-action-trigger[data-list-action]');
    let listAction = listActionElement === null ? '' : listActionElement.dataset.listAction;
    switch (listAction) {
      case 'select': {
        if (event.target.checked) {
          this.selectedItemIds.add(itemId);
        } else {
          this.selectedItemIds.delete(itemId);
        }
        this.renderingItemSelection();
        break;
      }
      default: {
        break;
      }
    }
  }

  renderingItemSelection() {


  }

}
